==> libgda-0.8.104.tar.gz: libgda-0.8.104/providers/default/gda-default-recordset.c <==
/* GDA Default provider
 * Copyright (C) 1998-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *      Carlos Perell Marn <carlos@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <bonobo/bonobo-i18n.h>
#include "gda-default-recordset.h"

#define OBJECT_DATA_RECSET_HANDLE "GDA_Default_RecsetHandle"

/*
 * Private functions
 */

static GdaRow *
fetch_func (GdaServerRecordset *recset, gulong rownum)
{
	return NULL;
}

static GdaRowAttributes *
describe_func (GdaServerRecordset *recset)
{
	return NULL;
}

/*
 * Public functions
 */

GdaServerRecordset *
gda_default_recordset_new (GdaServerConnection *cnc, DEFAULT_Recordset *drecset)
{
	GdaServerRecordset *recset;

	g_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), NULL);
	g_return_val_if_fail (drecset != NULL, NULL);

	return NULL;
}

==> libgda-0.8.190.tar.gz: libgda-0.8.190/providers/default/gda-default-recordset.c <==
/* GDA Default provider
 * Copyright (C) 1998-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *      Carlos Perell Marn <carlos@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <libgda/gda-intl.h>
#include "gda-default-recordset.h"

#define OBJECT_DATA_RECSET_HANDLE "GDA_Default_RecsetHandle"

/*
 * Private functions
 */

static GdaRow *
fetch_func (GdaRecordset *recset, gulong rownum)
{
	return NULL;
}

static GdaRowAttributes *
describe_func (GdaRecordset *recset)
{
	return NULL;
}

/*
 * Public functions
 */

GdaRecordset *
gda_default_recordset_new (GdaConnection *cnc, DEFAULT_Recordset *drecset)
{
	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
	g_return_val_if_fail (drecset != NULL, NULL);

	return NULL;
}
